summaryrefslogtreecommitdiffstats
path: root/karbon/karbon_factory.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /karbon/karbon_factory.cc
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'karbon/karbon_factory.cc')
-rw-r--r--karbon/karbon_factory.cc18
1 files changed, 9 insertions, 9 deletions
diff --git a/karbon/karbon_factory.cc b/karbon/karbon_factory.cc
index d751b295..e230dea7 100644
--- a/karbon/karbon_factory.cc
+++ b/karbon/karbon_factory.cc
@@ -41,16 +41,16 @@ KarbonResourceServer* KarbonFactory::s_rserver = 0;
KInstance* KarbonFactory::s_instance = 0L;
KAboutData* KarbonFactory::s_aboutData = 0L;
-KarbonFactory::KarbonFactory( QObject* parent, const char* name )
- : KoFactory( parent, name )
+KarbonFactory::KarbonFactory( TQObject* tqparent, const char* name )
+ : KoFactory( tqparent, name )
{
instance();
KarbonToolRegistry::instance();
// Load plugins
- KTrader::OfferList offers = KTrader::self() -> query(QString::fromLatin1("Karbon/CoreModule"),
- QString::fromLatin1("Type == 'Service'"));
+ KTrader::OfferList offers = KTrader::self() -> query(TQString::tqfromLatin1("Karbon/CoreModule"),
+ TQString::tqfromLatin1("Type == 'Service'"));
KTrader::OfferList::ConstIterator iter;
@@ -59,7 +59,7 @@ KarbonFactory::KarbonFactory( QObject* parent, const char* name )
KService::Ptr service = *iter;
int errCode = 0;
KParts::Plugin* plugin =
- KParts::ComponentFactory::createInstanceFromService<KParts::Plugin> ( service, this, 0, QStringList(), &errCode);
+ KParts::ComponentFactory::createInstanceFromService<KParts::Plugin> ( service, this, 0, TQStringList(), &errCode);
if ( plugin )
kdDebug() << "found plugin " << service -> property("Name").toString() << "\n";
}
@@ -76,18 +76,18 @@ KarbonFactory::~KarbonFactory()
}
KParts::Part*
-KarbonFactory::createPartObject( QWidget* parentWidget, const char* widgetName,
- QObject* parent, const char* name, const char* classname, const QStringList& )
+KarbonFactory::createPartObject( TQWidget* tqparentWidget, const char* widgetName,
+ TQObject* tqparent, const char* name, const char* classname, const TQStringList& )
{
// If classname is "KoDocument", our host is a koffice application
// otherwise, the host wants us as a simple part, so switch to readonly and
// single view.
bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
// parentWidget and widgetName are used by KoDocument for the
// "readonly+singleView" case.
KarbonPart* part =
- new KarbonPart( parentWidget, widgetName, parent, name, !bWantKoDocument );
+ new KarbonPart( tqparentWidget, widgetName, tqparent, name, !bWantKoDocument );
if( !bWantKoDocument )
part->setReadWrite( false );
@@ -76,18 +76,18 @@ KarbonFactory::~KarbonFactory()
// single view.
bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
- // parentWidget and widgetName are used by KoDocument for the
+ // tqparentWidget and widgetName are used by KoDocument for the
// "readonly+singleView" case.
KarbonPart* part =